package com.cusc.nirvana.user.rnr.customer.config;

import com.alibaba.fastjson.JSON;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpMethod;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Description: mvc日志输出
 * <br />
 * CreateDate 2021-11-12 10:26
 *
 * @author yuyi
 **/
@Aspect
@Component
public class WebLogAspect {

	private final static Logger LOGGER = LoggerFactory.getLogger(WebLogAspect.class);

	/**
	 * 以 controller 包下定义的所有请求为切入点
	 */
	@Pointcut("execution(* com.cusc.nirvana.user.rnr.customer.controller.*.*(..))")
	public void webLog() {
	}

	/**
	 * 环绕
	 *
	 * @param proceedingJoinPoint
	 * @return
	 * @throws Throwable
	 */
	@Around("webLog()")
	public Object doAround(ProceedingJoinPoint proceedingJoinPoint) throws Throwable {
		long startTime = System.currentTimeMillis();
		String requestId = CuscStringUtils.generateUuid();

		ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
		HttpServletRequest request = sra.getRequest();

		String url = request.getRequestURL().toString();
		String method = request.getMethod();

		String params =  "";
		//获取请求参数集合并进行遍历拼接
		if (HttpMethod.POST.name().equals(method)) {
			Object[] args = proceedingJoinPoint.getArgs();
			List<Object> filterArgsList = Arrays.stream(args).filter(arg -> !(arg instanceof ServletResponse)).collect(Collectors.toList());
			params = JSON.toJSONString(filterArgsList, new CustomerIgnoreBase64ImgJsonSerializeFilter());
		} else if (HttpMethod.GET.name().equals(method)) {
			params = request.getQueryString();
		}

		LOGGER.info("requestId:{} , request url:{} , method:{} , params:{}", requestId, url, method, params);
		// result的值就是被拦截方法的返回值
		Object result = null;
		try{
			result = proceedingJoinPoint.proceed();
			LOGGER.info("requestId:{} , response url:{} , result:{} , cost:{} ms", requestId, url,
					JSON.toJSONString(result, new CustomerIgnoreBase64ImgJsonSerializeFilter()),
					System.currentTimeMillis() - startTime);
		}catch (Exception e) {
			LOGGER.error("requestId:{} , response url:{} , e:{}, cost:{} ms", requestId, url,
					e, System.currentTimeMillis() - startTime);
			if (e instanceof CuscUserException) {
				CuscUserException cuscUserException = (CuscUserException) e;
				result = Response.createError(e.getMessage(),StringUtils.isBlank(cuscUserException.getCode()) ? "-1":cuscUserException.getCode());
			}
			throw e;
		}
		return result;
	}
}
