package com.cusc.nirvana.user.rnr.customer.controller;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.customer.dto.LivenessCallbackReqDTO;
import com.cusc.nirvana.user.rnr.customer.dto.PersonalH5CallBackRespDTO;
import com.cusc.nirvana.user.rnr.customer.dto.PersonalH5ReqDTO;
import com.cusc.nirvana.user.rnr.customer.dto.PersonalH5RespDTO;
import com.cusc.nirvana.user.rnr.customer.service.IPersonalH5Service;
import com.cusc.nirvana.user.rnr.customer.service.ValidationService;
import com.cusc.nirvana.user.rnr.customer.util.ValidationUtil;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * @className: PersonalH5Controller
 * @description: 车主H5
 * @author: jk
 * @date: 2022/6/7 11:03
 * @version: 1.0
 **/
@RestController
@RequestMapping("/personal/h5")
public class PersonalH5Controller {

    @Resource
    private IPersonalH5Service personalH5Service;

    @Resource
    private ValidationService validationService;

    /**
     * h5自然人实名认证
     */
    @ApiOperation(value = "提交自然人实名认证", notes = "提交自然人实名认证")
    @PostMapping("/submitRnr")
    public Response<PersonalH5RespDTO> submitRnr(@Valid @RequestBody PersonalH5ReqDTO bean) {
        Response response = validationService.checkEffectiveTime();
        if(!response.isSuccess()){
            return response;
        }
        return Response.createSuccess(personalH5Service.submitRnrH5(bean));
    }

    /**
     * 活体检测结果回调
     */
    @ApiOperation(value = "活体检测结果回调", notes = "活体检测结果回调")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "操作成功返回数据类型", response = Response.class)})
    @RequestMapping(value = "/livenessCallback", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public Response<PersonalH5CallBackRespDTO> afreshLivenessUrl(@Valid @RequestBody LivenessCallbackReqDTO bean) {
        return Response.createSuccess(personalH5Service.afreshLivenessUrl(bean));
    }


    @ApiOperation(value = "校验是否在有效时间内", notes = "校验是否在有效时间内")
    @RequestMapping(value = "/checkEffectiveTime", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public Response checkEffectiveTime() {
        Response response =validationService.checkEffectiveTime();
        if(!response.isSuccess()){
            return response;
        }
        return response;
    }

}
