package com.cusc.nirvana.user.rnr.customer.dto;

import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.customer.constants.CustomerTypeEnum;
import com.cusc.nirvana.user.rnr.mg.dto.RnrRelationDTO;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.util.CollectionUtils;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.List;

 /**
   * @author: jk
   * @description:
   * @date: 2022/6/7 11:12
   * @version: 1.0
   * @Param:  
   * @Return: 
   */ 
@Data
public class PersonalH5ReqDTO implements Serializable {
    private static final long serialVersionUID = -407770263820788123L;



    @ApiModelProperty(value = "车辆VIN号")
    @NotBlank(message = "车辆VIN号不能为空")
    private String vin;

    @ApiModelProperty(value = "客户类型 0：新车车主 1：二手车车主")
    @NotNull(message = "客户类型不能为空")
    private Integer customerType;

    @ApiModelProperty(value = "是否委托人代办 true：是 false：否")
    @NotNull(message = "是否委托人不能为空")
    private Boolean isConsigner;

    @ApiModelProperty(value = "委托人信息")
    private ConsignerInfoDTO consignerInfo;

    @ApiModelProperty(value = "ICCID编号集合")
    @NotEmpty(message = "ICCID不能为空")
    private List<String> iccidList;

    @ApiModelProperty(value = "车主姓名")
//    @NotBlank(message = "车主姓名不能为空")
    private String fullName;

    @ApiModelProperty(value = "性别")
    @NotBlank(message = "性别不能为空")
    private String gender;

    @ApiModelProperty(value = "证件类型 " +
            "'IDCARD'：居民身份证 " +
            "'HOUSEHOLD'：户口簿 " +
            "'PLAIDCARD'：中国人民解放军军人身份证件 " +
            "'CAPFIDCARD'：中国人民武装警察身份证件 " +
            "'HKIDCARD'：港澳居民来往内地通行证 " +
            "'TAIBAOZHENG'：台湾居民来往大陆通行证 " +
            "'PASSPORT'：外国公民护照 " +
            "'HKRESIDENCECARD'：港澳居民居住证 " +
            "'TWRESIDENCECARD'：台湾居民居住证")
    @NotBlank(message = "证件类型不能为空")
    private String certType;

    @ApiModelProperty(value = "证件号码")
    private String certNumber;

    @ApiModelProperty(value = "证件地址")
    @NotBlank(message = "证件地址不能为空")
    private String certAddress;

    @ApiModelProperty(value = "证件照片")
    @NotEmpty(message = "证件照片不能为空")
    private List<String> certPic;

	 @ApiModelProperty(value = "证件有效期开始时间")
	 @NotBlank(message = "证件有效期开始时间不能为空")
	 private String certEffectiveDate;

    @ApiModelProperty(value = "证件有效期")
    @NotBlank(message = "证件有效期不能为空")
    private String certExpirationDate;

    @ApiModelProperty(value = "活体验证视频")
    private String liveVerificationVideo;

    @ApiModelProperty(value = "通讯地址")
    private String contactAddress;

    @ApiModelProperty(value = "入网合同")
    @NotEmpty(message = "入网合同不能为空")
    private List<String> contractPic;

    @ApiModelProperty(value = "购车合同")
    private List<String> purchaseContractPic;

    @ApiModelProperty(value = "购车发票")
    private List<String> purchaseInvoicePic;

    @ApiModelProperty(value = "过户证明")
    private List<String> transferCertificatePic;

    @ApiModelProperty(value = "车主手机号码")
//    @NotBlank(message = "车主手机号码不能为空")
    private String phone;

    @ApiModelProperty(value = "短信验证码")
    private String verificationCode;

    @ApiModelProperty(value = "责任告知书")
    private List<String> dutyPic;


    public void checkParam(){
		RnrRelationDTO rnrRelationDTO = new RnrRelationDTO();
		if (customerType == CustomerTypeEnum.USED_CAR_OWNER.getCode()) {
			//二手车车主
			if (CollectionUtils.isEmpty(purchaseContractPic)) {
				throw new CuscUserException("","购车合同为空");
			}

			if (CollectionUtils.isEmpty(purchaseInvoicePic)) {
				throw new CuscUserException("","购车发票为空");
			}
			if (CollectionUtils.isEmpty(transferCertificatePic)) {
				throw new CuscUserException("","过户证明为空");
			}
		}
	}
}
