package com.cusc.nirvana.user.rnr.customer.service.impl;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.customer.constants.CompanyTypeEnum;
import com.cusc.nirvana.user.rnr.customer.constants.IndustryTypeEnum;
import com.cusc.nirvana.user.rnr.customer.dto.DicDTO;
import com.cusc.nirvana.user.rnr.customer.service.IBaseConfigService;
import com.cusc.nirvana.user.rnr.fp.constants.LivenessActionSeqEnum;
import com.cusc.nirvana.user.rnr.fp.constants.LivenessTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CertTypeEnum;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class BaseConfigServiceImpl implements IBaseConfigService {
    private static final Set<String> PERSON_CERTTYPE_CODE_SET = new HashSet<String>();
    private static final Set<String> COMPANY_CERTTYPE_CODE_SET = new HashSet<>();

    static {
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.IDCARD.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.HKIDCARD.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.PASSPORT.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.PLA.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.POLICEPAPER.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.TAIBAOZHENG.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.HKRESIDENCECARD.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.TWRESIDENCECARD.getCode());
        //PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.SOCIAL_ORG_LEGAL_PERSON_CERT.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.RESIDENCE.getCode());
        PERSON_CERTTYPE_CODE_SET.add(CertTypeEnum.OTHER.getCode());

        COMPANY_CERTTYPE_CODE_SET.add(CertTypeEnum.UNITCREDITCODE.getCode());
        COMPANY_CERTTYPE_CODE_SET.add(CertTypeEnum.BUSINESS_LICENSE_NO.getCode());
    }


    @Override
    public Response getDicData(String tenantNo) {
        Map<String, Object> dicMap = new HashMap<>();
        dicMap.put("certType", wrapPersonCertTypeDicList());
        dicMap.put("companyCertType", wrapCompanyCertTypeDicList());
        dicMap.put("companyType", wrapCompanyTypeDicList());
        dicMap.put("industryType", wrapIndustryTypeDicList());
        dicMap.put("livenessType", wrapLivenessTypeDicList());
        dicMap.put("livenessActionSeq", wrapLivenessActionSeqDicList());
        return Response.createSuccess(dicMap);
    }

    private Object wrapLivenessActionSeqDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (LivenessActionSeqEnum item : LivenessActionSeqEnum.values()) {
            DicDTO dicItem = new DicDTO();
            dicItem.setLabel(item.getName());
            dicItem.setValue(item.getCode());
            list.add(dicItem);
        }
        return list;
    }

    private Object wrapLivenessTypeDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (LivenessTypeEnum item : LivenessTypeEnum.values()) {
            DicDTO dicItem = new DicDTO();
            dicItem.setLabel(item.getName());
            dicItem.setValue(item.getCode());
            list.add(dicItem);
        }
        return list;
    }


    private List<DicDTO> wrapIndustryTypeDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (IndustryTypeEnum item : IndustryTypeEnum.values()) {
            DicDTO dicItem = new DicDTO();
            dicItem.setLabel(item.getValue());
            dicItem.setValue(item.getCode() + "");
            list.add(dicItem);
        }
        return list;
    }

    private List<DicDTO> wrapCompanyCertTypeDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (CertTypeEnum item : CertTypeEnum.values()) {
            DicDTO dicItem = new DicDTO();
            if (COMPANY_CERTTYPE_CODE_SET.contains(item.getCode())) {
                dicItem.setLabel(item.getName());
                dicItem.setValue(item.getCode());
                list.add(dicItem);
            }
        }
        return list;
    }

    private List<DicDTO> wrapCompanyTypeDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (CompanyTypeEnum item : CompanyTypeEnum.values()) {
            DicDTO dicItem = new DicDTO();
            dicItem.setLabel(item.getValue());
            dicItem.setValue(item.getCode() + "");
            list.add(dicItem);
        }
        return list;

    }

    private List<DicDTO> wrapPersonCertTypeDicList() {
        List<DicDTO> list = new ArrayList<>();
        for (CertTypeEnum item : CertTypeEnum.values()) {
            DicDTO dicItem = new DicDTO();
            if (PERSON_CERTTYPE_CODE_SET.contains(item.getCode())) {
                dicItem.setLabel(item.getName());
                dicItem.setValue(item.getCode());
                list.add(dicItem);
            }
        }
        return list;
    }
}
