package com.cusc.nirvana.user.rnr.customer.service.impl;

import com.alibaba.fastjson.JSON;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.customer.dto.FileDownloadDTO;
import com.cusc.nirvana.user.rnr.customer.service.IFileService;
import com.cusc.nirvana.user.rnr.fp.client.FileSystemClient;
import com.cusc.nirvana.user.rnr.fp.dto.FileRecordDTO;
import com.cusc.nirvana.user.rnr.fp.dto.FileUploadDTO;
import com.cusc.nirvana.user.rnr.fp.dto.ImageBase64DTO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import sun.misc.BASE64Decoder;

import javax.annotation.Resource;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 文件上传服务类
 *
 * @author huzl
 * @date 2022/04/18
 */
@Slf4j
@Service
public class FileServiceImpl implements IFileService {

    //文件后缀常量
    private static final List<String> FILE_SUFFIX_LIST =
            Arrays.asList("jpg","jpeg", "png", "gif", "bmp", "pdf", "mp4", "avi", "wav",
                    "rm","xls","xlsx","doc","docx");

    //    @Value("${rnr.fileSystem}")
//    private String fileServiceSrv;
//    @Value("${rnr.fileSelect}")
//    private String fileSelect;
    @Resource
    private FileSystemClient fileSystemClient;
    //@Resource
    //private RestTemplate nonLoadBalancedFile;

    @Override
    public Response<FileRecordDTO> upload(FileUploadDTO fileUploadDTO) {
//        String url = fileServiceSrv + "/file/upload/" + fileUploadDTO.getType();
//
//        final HttpHeaders headers = new HttpHeaders();
//        headers.setContentType(MediaType.MULTIPART_FORM_DATA);
//        if (StringUtils.isNotBlank(fileUploadDTO.getRootPath())) {
//            headers.set("rootPath", fileUploadDTO.getRootPath());
//        } else {
//            headers.set("rootPath", "rnr/");
//        }
//
//        MultiValueMap<String, Object> parameters = new LinkedMultiValueMap<>();
//        if (StringUtils.isNotBlank(fileUploadDTO.getPath())) {
//            parameters.add("path", fileUploadDTO.getPath());
//        }
//        if (StringUtils.isNotBlank(fileUploadDTO.getUuid())) {
//            parameters.add("uuid", fileUploadDTO.getUuid());
//        }
//
//        ByteArrayResource resource = null;
//        try {
//            resource = new ByteArrayResource(fileUploadDTO.getFile().getBytes()) {
//                @Override
//                public String getFilename() {
//                    return fileUploadDTO.getFile().getOriginalFilename();
//                }
//            };
//        } catch (IOException e) {
//            throw new AppGlobalException("读取文件流错误", e);
//        }
//
//        parameters.add("file", resource);
//
//        final HttpEntity<MultiValueMap<String, Object>> httpEntity = new HttpEntity<>(parameters, headers);
//        final ResponseEntity<String> entity = nonLoadBalancedFile.exchange(url, HttpMethod.POST, httpEntity, String
//        .class);
//        log.info("FileUpload, url:{},parameter:{},header:{},response:{}", url, fileUploadDTO, headers,
//                entity.toString());
//        Response<FileRecordDTO> response = JSONObject.parseObject(entity.getBody(),
//                new TypeReference<Response<FileRecordDTO>>(new Type[] {FileRecordDTO.class}) {
//                }.getType());
        return fileSystemClient.uploadImage(fileUploadDTO);
    }

    /**
     * 文件上传-重新写
     *
     * @param fileUploadDTO
     * @return
     */
    @Override
    public Response<FileRecordDTO> uploadTwo(FileUploadDTO fileUploadDTO) {
        Response<FileRecordDTO> response = null;
        try {
            String originalFilename = fileUploadDTO.getFile().getOriginalFilename();
            //检查文件后缀
            Response fileSuffixResp =  chechFileSuffix(originalFilename);
            if(!fileSuffixResp.isSuccess()){
                return fileSuffixResp;
            }
            //保存文件防止文件名重复。
//            String saveFileName = CuscStringUtils.generateUuid()
//                    + originalFilename.substring(originalFilename.lastIndexOf("."));
//
//            String path = "";
//            Object objectWriteResponse = null;

            response = fileSystemClient.uploadFile(fileUploadDTO);

            log.info("FileUpload response:{}", JSON.toJSON(response));
//            FileRecordDTO fileRecord =response.getData();
//            FileRecordDTO fileRecordDTO = new FileRecordDTO();
//            fileRecordDTO.setFileName(fileRecord.getFileName());
//            fileRecordDTO.setPath(fileRecord.getPath());
//            fileRecordDTO.setUuid(fileRecord.getUuid());
//            fileRecordDTO.setAccessUrl(fileRecord.getAccessUrl());
//            response = Response.createSuccess(fileRecordDTO);
        } catch (Exception e) {
            log.error("----upload-Exception---", e);
        }
        return response;
    }

    /**
     * 下载文件
     *
     * @param downloadDTO
     * @return
     */
    @Override
    public InputStream download(FileDownloadDTO downloadDTO) {
        byte[] result = downloadToByteArray(downloadDTO);
        return new ByteArrayInputStream(result);
    }

    /**
     * 下载文件
     *
     * @param downloadDTO
     * @return
     */
    @Override
    public byte[] downloadToByteArray(FileDownloadDTO downloadDTO) {
//        String url = fileServiceSrv + "/file/download/" + downloadDTO.getUuid();
//        log.debug("url: " + url);
//
//        log.info("下载文件-开始");
//        final ResponseEntity<byte[]> response = nonLoadBalancedFile.getForEntity(url, byte[].class);
//        ContentDisposition contentDisposition = response.getHeaders().getContentDisposition();
//        log.info("下载文件-结束");
//        try {
//            if (contentDisposition != null && CuscStringUtils.isNotEmpty(contentDisposition.getFilename())) {
//                downloadDTO.setFileName(URLDecoder.decode(contentDisposition.getFilename(), "utf-8"));
//            }
//        } catch (UnsupportedEncodingException e) {
//            log.warn("fileName decode error", e);
//        }
//        byte[] result = response.getBody();

        com.cusc.nirvana.user.rnr.fp.dto.FileDownloadDTO fileDownloadDTO =
                new com.cusc.nirvana.user.rnr.fp.dto.FileDownloadDTO();

        BeanUtils.copyProperties(downloadDTO, fileDownloadDTO);

        Response<ImageBase64DTO> response = fileSystemClient.getBase64(fileDownloadDTO);

        ImageBase64DTO imageBase64DTO = response.getData();
        byte[] result = null;
        try {
            result = new BASE64Decoder().decodeBuffer(imageBase64DTO.getBase64());
        } catch (IOException e) {
            log.warn("fileName decode error", e);
        }
        return result;
    }

//    @Override
//    public File downloadToLocal(FileDownloadDTO downloadDTO) throws Exception {
//        String url = fileServiceSrv + "/file/download/" + downloadDTO.getUuid();
//        String localFileName = "";
//        if (StringUtils.isNotEmpty(downloadDTO.getFileName())) {
//            localFileName = downloadDTO.getFileName();
//        }
//        String targetPath = generateTmpPath(localFileName);
//        //定义请求头的接收类型
//        AtomicBoolean isError = new AtomicBoolean(false);
//        MultiValueMap<String, String> headers = new HttpHeaders();
//        headers.add("Accept", MediaType.toString(Arrays.asList(MediaType.APPLICATION_OCTET_STREAM, MediaType.ALL)));
//        final HttpEntity<MultiValueMap<String, Object>> httpEntity = new HttpEntity(null, headers);
//        RequestCallback requestCallback = nonLoadBalancedFile.httpEntityCallback(httpEntity);
//        //对响应进行流式处理而不是将其全部加载到内存中
//        nonLoadBalancedFile.execute(url, HttpMethod.GET, requestCallback, clientHttpResponse -> {
//            HttpStatus statusCode = clientHttpResponse.getStatusCode();
//            if (statusCode != HttpStatus.OK) {
//                isError.set(true);
//            } else {
//                Files.copy(clientHttpResponse.getBody(), Paths.get(targetPath));
//            }
//            return null;
//        });
//        if (isError.get()) {
//            throw new Exception("文件下载失败");
//        }
//        return new File(targetPath);
//    }

    private String generateTmpPath(String fileName) {
        SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
        Date date = new Date();
        String path = format.format(date);
        StringBuilder targetPath = new StringBuilder();
        int index = fileName.lastIndexOf(".");

        String name = index == -1 ? fileName : fileName.substring(0, index);
        String ext = index == -1 ? "" : fileName.substring(index);
        String tmpPath = FileUtils.getTempDirectoryPath();
        targetPath.append(tmpPath).append((tmpPath.endsWith(File.separator) ? "" : File.separator)).append(path)
                .append(File.separator);
        File filePath = new File(targetPath.toString());
        if (!filePath.exists()) {
            filePath.mkdirs();
        }
        targetPath.append(name).append("_").append(System.currentTimeMillis()).append(ext);

        return targetPath.toString();
    }

    /**
     * Description: 文件后缀检查
     * <br />
     * CreateDate 2022-07-09 23:56:03
     *
     * @author yuyi
     **/
    private Response chechFileSuffix(String fileName) {
        int startIndex = fileName.lastIndexOf(".");
        if (startIndex <= 0) {
            return Response.createError("请上传规定的文件格式");
        }
        String suffixName = fileName.substring(startIndex+1).toLowerCase();
        if (FILE_SUFFIX_LIST.contains(suffixName)) {
            return Response.createSuccess();
        }
        return Response.createError("请上传规定的文件格式");
    }

}
