package com.cusc.nirvana.user.rnr.customer.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.auth.authentication.plug.user.UserSubjectUtil;
import com.cusc.nirvana.user.ciam.client.CiamUserClient;
import com.cusc.nirvana.user.ciam.dto.CiamUserDTO;
import com.cusc.nirvana.user.eiam.client.OrganizationClient;
import com.cusc.nirvana.user.eiam.dto.OrganizationDTO;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.customer.dto.*;
import com.cusc.nirvana.user.rnr.customer.service.IEnterpriseH5Service;
import com.cusc.nirvana.user.rnr.customer.service.IUserService;
import com.cusc.nirvana.user.rnr.fp.client.EnterpriseRnrClient;
import com.cusc.nirvana.user.rnr.fp.client.FpRnrClient;
import com.cusc.nirvana.user.rnr.fp.client.NewVinCardClient;
import com.cusc.nirvana.user.rnr.fp.client.SimVehicleRelClient;
import com.cusc.nirvana.user.rnr.fp.common.ResponseCode;
import com.cusc.nirvana.user.rnr.fp.constants.BizTypeEnum;
import com.cusc.nirvana.user.rnr.fp.dto.*;
import com.cusc.nirvana.user.rnr.mg.constants.*;
import com.cusc.nirvana.user.rnr.mg.dto.*;
import com.cusc.nirvana.user.util.CuscStringUtils;
import com.cusc.nirvana.user.util.DateUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * @className: IEnterpriseH5Impl
 * @description: 车主企业实名
 * @author: jk
 * @date: 2022/6/8 9:18
 * @version: 1.0
 **/
@Service
@Slf4j
public class IEnterpriseH5Impl implements IEnterpriseH5Service {

    @Autowired
    SmsServiceImpl smsService;

    @Resource
    private IUserService userService;

    @Resource
    private EnterpriseRnrClient enterpriseClient;

    @Resource
    private NewVinCardClient checkClient;

    private static final String SUCCESS_CODE = "0";

    @Autowired
    FpRnrClient fpRnrClient;

    @Value("${enterpriseH5Result:}")
    private String enterpriseH5Result;

    @Resource
    private SimVehicleRelClient simVehicleRelClient;

    @Resource
    private OrganizationClient organizationClient;

    @Resource
    private CiamUserClient ciamUserClient;

    @Override
    public EnterpriseH5RespDTO submitRnrH5(EnterpriseH5RequestDTO dto) {

        if (dto.getVinList().stream().distinct().count() != dto.getVinList().size()) {
            throw new CuscUserException(ResponseCode.SYSTEM_ERROR.getCode(),"请不要输入重复的vin");
        }

        for(int i = 0 ;i<dto.getVinList().size();i++){
            Response<List<VinIccidDTO>> iccids = simVehicleRelClient.getIccidByVin(dto.getVinList().get(i));
            if (!iccids.isSuccess()) {
                throw new CuscUserException(iccids.getCode(), iccids.getMsg());
            }
            for(VinIccidDTO iccidDetailDTO : iccids.getData()) {
                //如果为false不允许补录
                if (!iccidDetailDTO.getRealBySelf()) {
                    throw new CuscUserException(com.cusc.nirvana.user.rnr.customer.constants.ResponseCode.REAL_BY_SELF_FALSE.getCode(), com.cusc.nirvana.user.rnr.customer.constants.ResponseCode.REAL_BY_SELF_FALSE.getMsg());
                }
            }
        }

        //检查短信验证码
        //todo验证码校验被我屏蔽了
//        SmsRequestDTO smsRequestDTO = new SmsRequestDTO();
//        smsRequestDTO.setPhone(dto.getCorporationPhone());
//        smsRequestDTO.setTenantNo(UserSubjectUtil.getTenantNo());
//        smsRequestDTO.setBizType(BizTypeEnum.RNR.getCode());
//        smsRequestDTO.setCaptcha(dto.getVerificationCode());
//        Response smsResponse = smsService.checkSmsCaptcha(smsRequestDTO);
//        if (!smsResponse.isSuccess()) {
//            throw new CuscUserException(smsResponse.getCode(), smsResponse.getMsg());
//        }

        EnterpriseRnrCertificationInfoDTO certificationInfoDTO = new EnterpriseRnrCertificationInfoDTO();
        BeanUtils.copyProperties(dto, certificationInfoDTO);

        //构建relationDto
        String rnrId = CuscStringUtils.generateUuid();
        String tenantNo = UserSubjectUtil.getTenantNo();

//        String orgId = userService.getOrganId(UserSubjectUtil.getUserId(), tenantNo);

        OrganizationDTO organizationDTO = new OrganizationDTO();
        organizationDTO.setParentId("0");
        organizationDTO.setTenantNo(tenantNo);
        Response<List<OrganizationDTO>> orgResponse= organizationClient.queryByList(organizationDTO);
        if(!orgResponse.isSuccess()){
            throw new CuscUserException(orgResponse.getCode(), orgResponse.getMsg());
        }
        OrganizationDTO organizationDTO1= orgResponse.getData().get(0);
        String orgId = StringUtils.isNotEmpty(dto.getOrgId())?dto.getOrgId():organizationDTO1.getUuid();
        //公司信息
        MgRnrCompanyInfoDTO mgRnrCompanyInfoDTO = createCompanyInfoDTO(certificationInfoDTO, rnrId, tenantNo);

        //rnrInfo
        MgRnrInfoDTO rnrInfo = createRnrInfo(certificationInfoDTO, rnrId, tenantNo, mgRnrCompanyInfoDTO.getUuid());
        rnrInfo.setIsTrust(0);
        rnrInfo.setOrgId(orgId);

        //rnrOrder
        RnrOrderDTO rnrOrderDTO = createOrder(certificationInfoDTO, rnrInfo, rnrInfo.getUuid(), tenantNo, RnrOrderType.COMPANY_NEW_VEHICLE.getCode());
        rnrOrderDTO.setOrgId(orgId);

        //文件列表
        List<MgRnrFileDTO> fileDTOList = getMgRnrFileDTOs(certificationInfoDTO, null, rnrId, tenantNo,mgRnrCompanyInfoDTO.getUuid());

        //卡列表
        List<String> vinList = dto.getVinList();
        List<MgRnrCardInfoDTO> cardInfoDTOList = createCardInfoDtoByVinList(vinList, tenantNo, rnrId, rnrOrderDTO.getUuid());

        RnrRelationDTO rnrRelationDTO = new RnrRelationDTO();
        rnrRelationDTO.setCompanyInfo(mgRnrCompanyInfoDTO);
        rnrRelationDTO.setInfo(rnrInfo);
        rnrRelationDTO.setCardList(cardInfoDTOList);
        rnrRelationDTO.setOrder(rnrOrderDTO);
        rnrRelationDTO.setRnrFileList(fileDTOList);
        Response response = enterpriseClient.submitH5(rnrRelationDTO);
        if (!response.isSuccess()) {
            throw new CuscUserException(response.getCode(), response.getMsg());
        }

        EnterpriseH5RespDTO rnrH5RespDTO = new EnterpriseH5RespDTO();


        LiveLoginReqDTO loginUrlDto = new LiveLoginReqDTO();
        loginUrlDto.setOrderNo(rnrOrderDTO.getUuid());
        loginUrlDto.setCallBackUrl(enterpriseH5Result);
        // 调用云端接口
        Response<LiveLoginRespDTO> h5LiveLoginUrl = fpRnrClient.h5LiveLoginUrl(loginUrlDto);
        if (h5LiveLoginUrl.isSuccess()) {
            rnrH5RespDTO.setH5LivenessUrl(h5LiveLoginUrl.getData().getH5LiveLoginUrl());
        }
        rnrH5RespDTO.setRnrId(rnrId);
        rnrH5RespDTO.setOrderId(rnrOrderDTO.getUuid());
        return rnrH5RespDTO;
    }

    //公司信息
    private MgRnrCompanyInfoDTO createCompanyInfoDTO(EnterpriseRnrCertificationInfoDTO dto, String rnrId, String tenNo) {
        MgRnrCompanyInfoDTO mgRnrCompanyInfoDTO = new MgRnrCompanyInfoDTO();
        mgRnrCompanyInfoDTO.setUuid(CuscStringUtils.generateUuid());
        mgRnrCompanyInfoDTO.setRnrId(rnrId);
        mgRnrCompanyInfoDTO.setCompanyCertAddress(dto.getCompanyCertAddress());
        mgRnrCompanyInfoDTO.setCompanyCertNumber(dto.getCompanyCertNumber());
        mgRnrCompanyInfoDTO.setCompanyCertType(dto.getCompanyCertType());
        mgRnrCompanyInfoDTO.setCompanyContactAddress(dto.getCompanyContactAddress());
        mgRnrCompanyInfoDTO.setCompanyName(dto.getCompanyName());
        mgRnrCompanyInfoDTO.setCompanyType(dto.getCompanyType());
        mgRnrCompanyInfoDTO.setIndustryType(dto.getIndustryType());
        mgRnrCompanyInfoDTO.setTenantNo(tenNo);
        mgRnrCompanyInfoDTO.setCreator(UserSubjectUtil.getUserId());
        mgRnrCompanyInfoDTO.setOperator(UserSubjectUtil.getUserId());
        mgRnrCompanyInfoDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
        //是否是车企，数据库默认值是0
        if (dto.getIsVehicleCompany() == null) {
            dto.setIsVehicleCompany(0);
        }
        mgRnrCompanyInfoDTO.setIsVehicleCompany(dto.getIsVehicleCompany());
        return mgRnrCompanyInfoDTO;
    }

    //人信息
    private MgRnrInfoDTO createRnrInfo(EnterpriseRnrCertificationInfoDTO dto, String rnrId, String tenantNo, String uuid) {
        CiamUserDTO ciamUserDTO = new CiamUserDTO();
        ciamUserDTO.setUuid(UserSubjectUtil.getUserId());
        Response<CiamUserDTO> response = ciamUserClient.queryUserByUuid(ciamUserDTO);
        if(!response.isSuccess()){
            throw new CuscUserException(response.getCode(),response.getMsg());
        }
        MgRnrInfoDTO mgRnrInfoDTO = new MgRnrInfoDTO();
        mgRnrInfoDTO.setUuid(rnrId);
        mgRnrInfoDTO.setTenantNo(UserSubjectUtil.getTenantNo());
        mgRnrInfoDTO.setSerial_number(CuscStringUtils.generateUuid());
        mgRnrInfoDTO.setIsCompany(1);
        mgRnrInfoDTO.setCertAddress(dto.getCorporationCertAddress());
        mgRnrInfoDTO.setCertType(dto.getCorporationCertType());
        mgRnrInfoDTO.setCertNumber(dto.getCorporationCertNumber());
        mgRnrInfoDTO.setContactAddress(dto.getCorporationContactAddress());
        mgRnrInfoDTO.setFullName(dto.getCorporationName());
        mgRnrInfoDTO.setGender(Integer.valueOf(dto.getCorporationGender()));
        mgRnrInfoDTO.setPhone(response.getData().getPhoneNum());
        mgRnrInfoDTO.setTenantNo(UserSubjectUtil.getTenantNo());
		mgRnrInfoDTO.setEffectiveDate(DateUtils.parseDate(dto.getCorporationCertEffectiveDate(),"yyyy-MM-dd"));
        mgRnrInfoDTO.setExpiredDate(dto.getCorporationCertExpirationDate());
        //mgRnrInfoDTO.setUuid(CuscStringUtils.generateUuid());
        mgRnrInfoDTO.setCreator(UserSubjectUtil.getUserId());
        mgRnrInfoDTO.setOperator(UserSubjectUtil.getUserId());
        mgRnrInfoDTO.setIsCompany(1);
        mgRnrInfoDTO.setRnrCompanyId(uuid);
        mgRnrInfoDTO.setRnrStatus(0);
        mgRnrInfoDTO.setUserId(UserSubjectUtil.getUserId());
        mgRnrInfoDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
        return mgRnrInfoDTO;
    }

    //创建工单
    private RnrOrderDTO createOrder(EnterpriseRnrCertificationInfoDTO dto, MgRnrInfoDTO rnrInfoDTO, String uuid, String tenNo, int orderType) {
        RnrOrderDTO rnrOrderDTO = new RnrOrderDTO();
        rnrOrderDTO.setUuid(CuscStringUtils.generateUuid());
        rnrOrderDTO.setOrderType(orderType);
        rnrOrderDTO.setRnrId(uuid);
        rnrOrderDTO.setAuditType(RnrOrderAuditTypeEnum.MANUAL.getCode());
        rnrOrderDTO.setAutoRnr(false);
        rnrOrderDTO.setIsBatchOrder(1);
        rnrOrderDTO.setSerialNumber(rnrInfoDTO.getSerial_number());
        rnrOrderDTO.setOrderSource(RnrOrderSourceEnum.H5_CUSTOMER.getCode());
        rnrOrderDTO.setCreator(UserSubjectUtil.getUserId());
        rnrOrderDTO.setOperator(UserSubjectUtil.getUserId());
        rnrOrderDTO.setTenantNo(tenNo);
        rnrOrderDTO.setOrderStatus(RnrOrderStatusEnum.TO_EXAMINE.getCode());
        rnrOrderDTO.setSendWorkOrder(true);
        rnrOrderDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
        return rnrOrderDTO;
    }

    //卡信息
    private List<MgRnrCardInfoDTO> createCardInfoDTOs(EnterpriseRnrCertificationInfoDTO dto, RnrRelationDTO relationDTO, String tenantNo, String rnrId, String uuid, List<VinCardDTO> vinCardDTOS) {
        List<MgRnrCardInfoDTO> cardInfoDTOS = new ArrayList<>();
        for (VinCardDTO cardDTO : vinCardDTOS) {
            MgRnrCardInfoDTO mgRnrCardInfoDTO = new MgRnrCardInfoDTO();
            mgRnrCardInfoDTO.setUuid(CuscStringUtils.generateUuid());
            mgRnrCardInfoDTO.setIccid(cardDTO.getIccid());
            mgRnrCardInfoDTO.setTenantNo(tenantNo);
            mgRnrCardInfoDTO.setIotId(cardDTO.getVin());
            mgRnrCardInfoDTO.setRnrId(rnrId);
            mgRnrCardInfoDTO.setOrderId(uuid);
            mgRnrCardInfoDTO.setCreator(UserSubjectUtil.getUserId());
            mgRnrCardInfoDTO.setOperator(UserSubjectUtil.getUserId());
            mgRnrCardInfoDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
            cardInfoDTOS.add(mgRnrCardInfoDTO);
        }
        return cardInfoDTOS;
    }

    private List<MgRnrFileDTO> getMgRnrFileDTOs(EnterpriseRnrCertificationInfoDTO requestDTO, RnrRelationDTO rnrRelationDTO, String uuid, String tenNo,String companyId) {
        List<MgRnrFileDTO> mgRnrFileDTOS = new ArrayList<>();
        //企业实名认证授权书
        List<String> authorizationLetterPic = requestDTO.getAuthorizationLetterPic();
        for (int i = 0; i < authorizationLetterPic.size(); i++) {
            mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO, authorizationLetterPic.get(i), RnrFileType.ENTERPRISE_AUTH_FILE.getCode(), "0", uuid, tenNo, companyId));
        }

        //企业证件照
        List<String> licenseImages = requestDTO.getLicenseImages();
        for (int i = 0; i < licenseImages.size(); i++) {
            mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO, licenseImages.get(i), RnrFileType.ENTERPRISE_PIC.getCode(), "0", uuid, tenNo, companyId));
        }
        //责任人证件照
        List<String> corporationPhotoPic = requestDTO.getCorporationPhotoPic();
        for (int i = 0; i < corporationPhotoPic.size(); i++) {
            int index = 0;
            if (i != 0) {
                index = 1;
            }
            mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO, corporationPhotoPic.get(i), getFileType(requestDTO.getCorporationCertType(), index), "0", uuid, tenNo, companyId));
        }
        //活体视频
        if (StringUtils.isNotBlank(requestDTO.getLiveVerificationVideo())) {
            mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO, requestDTO.getLiveVerificationVideo(), RnrFileType.LIVENESS_VIDEO.getCode(), "0", uuid, tenNo, companyId));
        }

        //责任告知书
        if (!CollectionUtils.isEmpty(requestDTO.getDutyPic())) {
            for (String duty:requestDTO.getDutyPic()) {
                mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO,duty,RnrFileType.DUTY_FILE.getCode(),"0",uuid,tenNo,companyId));
            }
        }
        //入网合同
        if (!CollectionUtils.isEmpty(requestDTO.getContractPic())) {
            for (String contact:requestDTO.getContractPic()) {
                mgRnrFileDTOS.add(newFileDTO(rnrRelationDTO,contact,RnrFileType.VEHUCLE_BIND.getCode(),"0",uuid,tenNo,companyId));
            }
        }
        return mgRnrFileDTOS;
    }

    private MgRnrFileDTO newFileDTO(RnrRelationDTO rnrRelationDTO, String pic, Integer fileType, String liasionId, String uuid, String tenNo,String companyId) {
        MgRnrFileDTO mgRnrFileDTO = new MgRnrFileDTO();
        mgRnrFileDTO.setUuid(CuscStringUtils.generateUuid());
        mgRnrFileDTO.setRnrId(uuid);
        mgRnrFileDTO.setFileType(fileType);
        mgRnrFileDTO.setFileSystemId(pic);
        mgRnrFileDTO.setTenantNo(tenNo);
        mgRnrFileDTO.setLiaisonId(liasionId);
        mgRnrFileDTO.setCreator(UserSubjectUtil.getUserId());
        mgRnrFileDTO.setOperator(UserSubjectUtil.getUserId());
        mgRnrFileDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
        mgRnrFileDTO.setTenantNo(tenNo);
        mgRnrFileDTO.setRnrCompanyId(companyId);
        return mgRnrFileDTO;
    }

    /**
     * 获取文件类型
     *
     * @param certType 证书类型
     * @param index    索引
     */
    private Integer getFileType(String certType, int index) {
        CertTypeEnum certTypeEnum = Arrays.stream(CertTypeEnum.values())
                .filter(c -> StringUtils.equalsIgnoreCase(c.getCode(), certType))
                .findFirst().get();
        switch (certTypeEnum) {
            case IDCARD:
                if (index == 0) return RnrFileType.IDENTITY_CARD_BACK.getCode();
                if (index == 1) return RnrFileType.IDENTITY_CARD_FRONT.getCode();
                return null;
            case PLA:
                if (index == 0) return RnrFileType.OFFICIAL_CARD_FRONT.getCode();
                if (index == 1) return RnrFileType.OFFICIAL_CARD_BACK.getCode();
            case HKIDCARD:
                if (index == 0) return RnrFileType.HK_MACAO_PASSPORT_FRONT.getCode();
                if (index == 1) return RnrFileType.HK_MACAO_PASSPORT_BACK.getCode();
            case TAIBAOZHENG:
                if (index == 0) return RnrFileType.TAIWAN_CARD_FRONT.getCode();
                if (index == 1) return RnrFileType.TAIWAN_CARD_BACK.getCode();
            case PASSPORT:
                if (index == 0) return RnrFileType.FOREIGN_NATIONAL_PASSPORT_FRONT.getCode();
                if (index == 1) return RnrFileType.FOREIGN_NATIONAL_PASSPORT_BACK.getCode();
            case POLICEPAPER:
                if (index == 0) return RnrFileType.POLICE_CARD_FRONT.getCode();
                if (index == 1) return RnrFileType.POLICE_CARD_BACK.getCode();
            case HKRESIDENCECARD:
                if (index == 0) return RnrFileType.HK_MACAO_RESIDENCE_PERMIT_FRONT.getCode();
                if (index == 1) return RnrFileType.HK_MACAO_RESIDENCE_PERMIT_BACK.getCode();
            case TWRESIDENCECARD:
                if (index == 0) return RnrFileType.TAIWAN_RESIDENCE_PERMIT_FRONT.getCode();
                if (index == 1) return RnrFileType.TAIWAN_RESIDENCE_PERMIT_BACK.getCode();
            case RESIDENCE:
                if (index == 0) return RnrFileType.RESIDENCE_BOOKLET_FRONT.getCode();
                if (index == 1) return RnrFileType.RESIDENCE_BOOKLET_BACK.getCode();
            case OTHER:
                if (index == 0) return RnrFileType.OTHER.getCode();
                if (index == 1) return RnrFileType.OTHER.getCode();
            default:
                return null;
        }
    }

    private List<MgRnrCardInfoDTO> createCardInfoDtoByVinList(List<String> vinList, String tenantNo, String rnrId, String orderId) {
        List<MgRnrCardInfoDTO> cardInfoDTOList = Collections.synchronizedList(new ArrayList<>());
        String creator = UserSubjectUtil.getUserId();
        String operator = UserSubjectUtil.getUserId();
        vinList.stream().forEach(vin -> {
            VinCardQueryDTO dto = new VinCardQueryDTO();
            dto.setVin(vin);
            Response<VinCardResultDTO> vinCardResultResponse = checkClient.queryUnBindCardByVin(dto);
            log.info("createCardInfoDtoByVinList vin = {},reponse = {}", vin, JSONObject.toJSONString(vinCardResultResponse));
            if (null == vinCardResultResponse || !vinCardResultResponse.isSuccess()
                    || null == vinCardResultResponse.getData()
                    || CollectionUtils.isEmpty(vinCardResultResponse.getData().getIccidList())) {
                throw new CuscUserException(ResponseCode.SYSTEM_ERROR.getCode(), "未查询到卡信息");
            }

            List<String> iccidList = vinCardResultResponse.getData().getIccidList();

            for (String iccid : iccidList) {
                MgRnrCardInfoDTO mgRnrCardInfoDTO = new MgRnrCardInfoDTO();
                mgRnrCardInfoDTO.setUuid(CuscStringUtils.generateUuid());
                mgRnrCardInfoDTO.setIccid(iccid);
                mgRnrCardInfoDTO.setTenantNo(tenantNo);
                mgRnrCardInfoDTO.setIotId(vin);
                mgRnrCardInfoDTO.setRnrId(rnrId);
                mgRnrCardInfoDTO.setOrderId(orderId);
                mgRnrCardInfoDTO.setCreator(creator);
                mgRnrCardInfoDTO.setOperator(operator);
                mgRnrCardInfoDTO.setRnrBizzType(RnrBizzTypeEnum.Bind.getCode());
                cardInfoDTOList.add(mgRnrCardInfoDTO);
            }
        });
        return cardInfoDTOList;
    }

    @Override
    public EnterpriseH5CallBackRespDTO afreshLivenessUrl(LivenessCallbackReqDTO bean) {
        EnterpriseH5CallBackRespDTO respDTO = new EnterpriseH5CallBackRespDTO();
        boolean success = bean.getCode().equals(SUCCESS_CODE);
        if (success) {
            // 调用云端接口 
            //todo 接口调用可能有问题 应该为get请求
            LiveLoginReqDTO liveLoginReqDTO = new LiveLoginReqDTO();
            liveLoginReqDTO.setOrderNo(bean.getOrderNo());
            Response<LivenessResultDTO> livenessResult = fpRnrClient.h5LivenessResult(liveLoginReqDTO);
            if (null == livenessResult || !livenessResult.isSuccess() || null == livenessResult.getData()) {
                //没有查询到 活体视屏 和 照片 再次拉起腾讯活体H5
                LiveLoginReqDTO loginUrlDto = new LiveLoginReqDTO();
                loginUrlDto.setOrderNo(bean.getOrderNo());
                loginUrlDto.setCallBackUrl(enterpriseH5Result);
                // 调用云端接口
                Response<LiveLoginRespDTO> h5LiveLoginUrl = fpRnrClient.h5LiveLoginUrl(loginUrlDto);
                respDTO.setStatus(2);
                if (h5LiveLoginUrl.isSuccess()) {
                    respDTO.setH5LivenessUrl(h5LiveLoginUrl.getData().getH5LiveLoginUrl());
                }
            } else {
                LivenessResultDTO livenessResultData = livenessResult.getData();
                EnterpriseH5CallBackRequestDTO callBackDto = new EnterpriseH5CallBackRequestDTO();
                callBackDto.setOrderNo(bean.getOrderNo());
                String[] livenessPhotos = new String[2];
                livenessPhotos[0] = livenessResultData.getPhotoId();
                livenessPhotos[1] = livenessResultData.getPhotoId();
                callBackDto.setLivenessPicFileId(livenessPhotos);
                callBackDto.setVideFileId(livenessResultData.getVideoFileId());
                Response<Integer> response = enterpriseClient.enterpriseRnrH5CallBack(callBackDto);
                if (!response.isSuccess() || null == response.getData()) {
                    throw new CuscUserException(response.getCode(), response.getMsg());
                }
                Integer data = response.getData();
                respDTO.setStatus(data);
            }
        } else {
            LiveLoginReqDTO loginUrlDto = new LiveLoginReqDTO();
            loginUrlDto.setOrderNo(bean.getOrderNo());
            loginUrlDto.setCallBackUrl(enterpriseH5Result);
            // 调用云端接口
            Response<LiveLoginRespDTO> h5LiveLoginUrl = fpRnrClient.h5LiveLoginUrl(loginUrlDto);
            if (h5LiveLoginUrl.isSuccess()) {
                respDTO.setH5LivenessUrl(h5LiveLoginUrl.getData().getH5LiveLoginUrl());
            }
            respDTO.setStatus(2);
        }

        return respDTO;
    }
}
