package com.cusc.nirvana.user.rnr.customer.service.impl;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.auth.authentication.plug.user.UserSubjectUtil;
import com.cusc.nirvana.user.eiam.client.OrganizationClient;
import com.cusc.nirvana.user.eiam.dto.OrganizationDTO;
import com.cusc.nirvana.user.eiam.dto.UserOrganDTO;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.customer.config.CustomerConfig;
import com.cusc.nirvana.user.rnr.customer.constants.ResponseCode;
import com.cusc.nirvana.user.rnr.customer.dto.ProtocolManageDTO;
import com.cusc.nirvana.user.rnr.customer.dto.ProtocolManageOneDTO;
import com.cusc.nirvana.user.rnr.customer.dto.ProtocolManageUrlDTO;
import com.cusc.nirvana.user.rnr.customer.service.IProtocolManageService;
import com.cusc.nirvana.user.rnr.fp.client.FileSystemClient;
import com.cusc.nirvana.user.rnr.fp.client.FpRnrProtocolManageClient;
import com.cusc.nirvana.user.rnr.fp.dto.FileDownloadDTO;
import com.cusc.nirvana.user.rnr.fp.dto.FileRecordDTO;
import com.cusc.nirvana.user.rnr.fp.dto.FpRnrProtocolManageDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @className: IProtocolManageServiceImpl
 * @description: 协议管理
 * @author: jk
 * @date: 2022/6/10 13:39
 * @version: 1.0
 **/
@Service
@Slf4j
public class IProtocolManageServiceImpl implements IProtocolManageService {

    @Resource
    private FpRnrProtocolManageClient fpRnrProtocolManageClient;

    @Resource
    private FileSystemClient fileSystemClient;

    @Resource
    private CustomerConfig customerConfig;
    @Resource
    private OrganizationClient organizationClient;

    @Override
    public Response<List<ProtocolManageDTO>> query() {
        //通过组织id出协议文件
        FpRnrProtocolManageDTO fpRnrProtocolManageDTO = new FpRnrProtocolManageDTO();
        fpRnrProtocolManageDTO.setTenantNo(UserSubjectUtil.getTenantNo());
        fpRnrProtocolManageDTO.setType("1");

        Response<List<FpRnrProtocolManageDTO>> responseList = fpRnrProtocolManageClient.queryByList(fpRnrProtocolManageDTO);

        if (!responseList.isSuccess()) {
            throw new CuscUserException(ResponseCode.SYS_BUSY.getCode(), ResponseCode.SYS_BUSY.getMsg());
        }
        List<FpRnrProtocolManageDTO> rnrProtocolManageDTOList = responseList.getData();
        if (CollectionUtils.isEmpty(rnrProtocolManageDTOList)) {
            return Response.createSuccess(rnrProtocolManageDTOList);
        }

        FpRnrProtocolManageDTO fpRnrProtocolManage = rnrProtocolManageDTOList.get(0);

        ProtocolManageDTO protocolManageDTO = new ProtocolManageDTO();
        String orgId = fpRnrProtocolManage.getOrgId();

        ProtocolManageOneDTO protocolManageOneDTO = new ProtocolManageOneDTO();

        BeanUtils.copyProperties(fpRnrProtocolManage, protocolManageOneDTO);
        //将对象属性转为map
        Map<String, String> map = convertToMap(protocolManageOneDTO);
        Map<String, Object> mapReturn = new HashMap<>();
        //并行调用查询文件路径
        map.entrySet().stream().map(entry -> {
            if(!StringUtils.isEmpty(entry.getValue())) {
                FileDownloadDTO fileRecordDTO = new FileDownloadDTO();
                fileRecordDTO.setUuid(entry.getValue());
                Response<FileRecordDTO> fileRecordDTOResponse = fileSystemClient.getUrl(fileRecordDTO);
                if (!fileRecordDTOResponse.isSuccess()) {
                    throw new CuscUserException(ResponseCode.SYS_BUSY.getCode(), ResponseCode.SYS_BUSY.getMsg());
                }
                ProtocolManageUrlDTO protocolManageUrlDTO = new ProtocolManageUrlDTO();
                protocolManageUrlDTO.setFileUrl(fileRecordDTOResponse.getData().getAccessUrl());
//                protocolManageUrlDTO.setFileName(fileRecordDTOResponse.getData().getFileName());
                protocolManageUrlDTO.setUuid(fileRecordDTOResponse.getData().getUuid());
                mapReturn.put(entry.getKey(), protocolManageUrlDTO);
            }else {
                mapReturn.put(entry.getKey(), "");
            }
            return mapReturn;
            //将路径塞进map对应的key中
//                entry.setValue(fileRecordDTOResponse.getData().getPath());
        }).collect(Collectors.toList());
        mapReturn.put("id", fpRnrProtocolManage.getId());
        mapReturn.put("uuid", fpRnrProtocolManage.getUuid());
        mapReturn.put("orgId", fpRnrProtocolManage.getOrgId());
        //通过反射将map key对应value塞进对应bean属性中
//            Object obj= toBean(map1,ProtocolManageDTO.class);
//            protocolManageDTO = (ProtocolManageDTO)obj;
//            protocolManageDTO.setOrgId(orgId);

        return Response.createSuccess(mapReturn);
    }

    @Override
    public Response<List<ProtocolManageDTO>> noLogin() {

        OrganizationDTO organizationDTO = new OrganizationDTO();
        organizationDTO.setTenantNo(customerConfig.getTenantNo());
        organizationDTO.setParentId("0");
        organizationDTO.setBizType(1);
        Response<List<OrganizationDTO>> re = organizationClient.queryByList(organizationDTO);
        if(!re.isSuccess()){
            throw new CuscUserException("","获取组织信息失败");
        }
        //通过组织id出协议文件
        FpRnrProtocolManageDTO fpRnrProtocolManageDTO = new FpRnrProtocolManageDTO();
        fpRnrProtocolManageDTO.setTenantNo(customerConfig.getTenantNo());
        fpRnrProtocolManageDTO.setType("1");

        Response<List<FpRnrProtocolManageDTO>> responseList = fpRnrProtocolManageClient.queryByList(fpRnrProtocolManageDTO);

        if (!responseList.isSuccess()) {
            throw new CuscUserException(ResponseCode.SYS_BUSY.getCode(), ResponseCode.SYS_BUSY.getMsg());
        }
        List<FpRnrProtocolManageDTO> rnrProtocolManageDTOList = responseList.getData();
        if (CollectionUtils.isEmpty(rnrProtocolManageDTOList)) {
            return Response.createSuccess(rnrProtocolManageDTOList);
        }

        FpRnrProtocolManageDTO fpRnrProtocolManage = rnrProtocolManageDTOList.get(0);

        ProtocolManageDTO protocolManageDTO = new ProtocolManageDTO();
        String orgId = fpRnrProtocolManage.getOrgId();

        ProtocolManageOneDTO protocolManageOneDTO = new ProtocolManageOneDTO();

        BeanUtils.copyProperties(fpRnrProtocolManage, protocolManageOneDTO);
        //将对象属性转为map
        Map<String, String> map = convertToMap(protocolManageOneDTO);
        Map<String, Object> mapReturn = new HashMap<>();
        //并行调用查询文件路径
        map.entrySet().stream().map(entry -> {
            if(!StringUtils.isEmpty(entry.getValue())) {
                FileDownloadDTO fileRecordDTO = new FileDownloadDTO();
                fileRecordDTO.setUuid(entry.getValue());
                Response<FileRecordDTO> fileRecordDTOResponse = fileSystemClient.getUrl(fileRecordDTO);
                if (!fileRecordDTOResponse.isSuccess()) {
                    throw new CuscUserException(ResponseCode.SYS_BUSY.getCode(), ResponseCode.SYS_BUSY.getMsg());
                }
                ProtocolManageUrlDTO protocolManageUrlDTO = new ProtocolManageUrlDTO();
                protocolManageUrlDTO.setFileUrl(fileRecordDTOResponse.getData().getAccessUrl());
//                protocolManageUrlDTO.setFileName(fileRecordDTOResponse.getData().getFileName());
                protocolManageUrlDTO.setUuid(fileRecordDTOResponse.getData().getUuid());
                if (StringUtils.isEmpty(UserSubjectUtil.getUserId()) && ("logoPc".equals(entry.getKey()) || "logoH5".equals(entry.getKey()))) {
                    mapReturn.put(entry.getKey(), protocolManageUrlDTO);
                }
            }else {
                mapReturn.put(entry.getKey(), "");
            }
            return mapReturn;
            //将路径塞进map对应的key中
//                entry.setValue(fileRecordDTOResponse.getData().getPath());
        }).collect(Collectors.toList());
        mapReturn.put("id", fpRnrProtocolManage.getId());
        mapReturn.put("uuid", fpRnrProtocolManage.getUuid());
        mapReturn.put("orgId", fpRnrProtocolManage.getOrgId());
        mapReturn.put("organName",re.getData().get(0).getOrganName());
        //通过反射将map key对应value塞进对应bean属性中
//            Object obj= toBean(map1,ProtocolManageDTO.class);
//            protocolManageDTO = (ProtocolManageDTO)obj;
//            protocolManageDTO.setOrgId(orgId);

        return Response.createSuccess(mapReturn);
    }

    //将java对象转为map为了方便调用文件查询接口
    public static Map<String, String> convertToMap(Object obj) {
        try {
            if (obj instanceof Map) {
                return (Map)obj;
            }
            Map<String, String> returnMap = org.apache.commons.beanutils.BeanUtils.describe(obj);

            returnMap.remove("class");
            return returnMap;
        } catch (IllegalAccessException e1) {
            e1.getMessage();
        } catch (InvocationTargetException e2) {
            e2.getMessage();
        } catch (NoSuchMethodException e3) {
            e3.getMessage();
        }
        return new HashMap();
    }
}
