package com.cusc.nirvana.user.rnr.customer.service.impl;


import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.auth.authentication.plug.user.UserSubjectUtil;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.customer.service.ISmsService;
import com.cusc.nirvana.user.rnr.customer.util.ValidationUtil;
import com.cusc.nirvana.user.rnr.fp.client.SmsClient;
import com.cusc.nirvana.user.rnr.fp.common.ResponseCode;
import com.cusc.nirvana.user.rnr.fp.dto.SmsRequestDTO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Description: 短信service
 * <br />
 * CreateDate 2022-04-16 15:11:41
 *
 * @author yuyi
 **/
@Service
@Slf4j
public class SmsServiceImpl implements ISmsService {

    @Autowired
    SmsClient smsClient;

    @Override
    public Response sendSmsRnr(SmsRequestDTO bean) {
        if (StringUtils.isBlank(bean.getBizType())) {
            return Response.createError("业务类型不能为空", ResponseCode.INVALID_DATA);
        }
        if (StringUtils.isBlank(bean.getPhone())) {
            return Response.createError("手机号不能为空", ResponseCode.INVALID_DATA);
        }
		//检查手机
		Response checkPhone = ValidationUtil.checkPhone(bean.getPhone());
		if (!checkPhone.isSuccess()) {
			throw new CuscUserException(checkPhone.getCode(),checkPhone.getMsg());
		}
        bean.setTenantNo(UserSubjectUtil.getTenantNo());
        return smsClient.sendSmsCaptcha(bean);
    }

    @Override
    public Response checkSmsCaptcha(SmsRequestDTO bean) {
        if (StringUtils.isBlank(bean.getBizType())) {
            return Response.createError("业务类型不能为空", ResponseCode.INVALID_DATA);
        }
        if (StringUtils.isBlank(bean.getPhone())) {
            return Response.createError("手机号不能为空", ResponseCode.INVALID_DATA);
        }
        if (StringUtils.isBlank(bean.getCaptcha())) {
            return Response.createError("验证码不能为空", ResponseCode.INVALID_DATA);
        }
        bean.setTenantNo(UserSubjectUtil.getTenantNo());
        return smsClient.checkSmsCaptcha(bean);
    }
}
