package com.cusc.nirvana.user.rnr.customer.service.impl;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.customer.constants.ResponseCode;
import com.cusc.nirvana.user.rnr.customer.dto.EffectiveTimeDTO;
import com.cusc.nirvana.user.rnr.customer.service.ValidationService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * @className: ValidationServiceImpl
 * @description: jk
 * @date: 2022/7/22 9:50
 * @version: 1.0
 **/
@Service
@Slf4j
public class ValidationServiceImpl implements ValidationService {

    @Value("${effectiveTime:}")
    private String effectiveTime;

    @Override
    public Response checkEffectiveTime() {
        EffectiveTimeDTO effectiveTimeDTO = new EffectiveTimeDTO();
        String startTime = effectiveTime.split("-")[0];
        String endTime = effectiveTime.split("-")[1];
        effectiveTimeDTO.setStartTime(startTime);
        effectiveTimeDTO.setEndTime(endTime);
        Calendar cal = Calendar.getInstance();
        int hour = cal.get(Calendar.HOUR_OF_DAY);
        int minute = cal.get(Calendar.MINUTE);
        int second = cal.get(Calendar.SECOND);
        String data = String.valueOf(hour) + ":"+String.valueOf(minute)+ ":"+String.valueOf(second);
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("HH:mm:ss");
        try {
            Date date = simpleDateFormat.parse(data);
            long ts = date.getTime();
            long start =  simpleDateFormat.parse(startTime).getTime();
            long end =  simpleDateFormat.parse(endTime).getTime();

            if(start >= ts || end <= ts){
                effectiveTimeDTO.setVisit(false);
                return Response.createError(ResponseCode.NO_EFFECTIVE_TIME.getMsg()+",\n服务时间为"+effectiveTime,ResponseCode.NO_EFFECTIVE_TIME.getCode());
            }
        } catch (ParseException e) {
            effectiveTimeDTO.setVisit(false);
            return Response.createError(ResponseCode.NO_EFFECTIVE_TIME.getMsg()+",\n服务时间为"+effectiveTime,ResponseCode.NO_EFFECTIVE_TIME.getCode());
        }
        effectiveTimeDTO.setVisit(true);
        return Response.createSuccess(effectiveTimeDTO);
    }
}
