package com.cusc.nirvana.user.rnr.customer.util;

import com.cusc.nirvana.user.auth.authentication.plug.user.UserSubjectUtil;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.fp.common.ResponseCode;
import com.cusc.nirvana.user.rnr.mg.constants.CertTypeEnum;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.util.CuscStringUtils;


/**
 * 文件处理类
 *
 * @author yubo
 * @since 2022-04-19 10:12
 */
public class FileUtil {

    //创建文件信息
    public static MgRnrFileDTO newFileDTO(String rnrId, String pic, Integer fileType, int rnrBizzType) {
        return newFileDTO(rnrId, pic, fileType, "0", rnrBizzType);
    }

    //创建文件信息
    public static MgRnrFileDTO newFileDTO(String rnrId, String pic, Integer fileType, String liasionId,int rnrBizzType) {
        MgRnrFileDTO mgRnrFileDTO = new MgRnrFileDTO();
        mgRnrFileDTO.setUuid(CuscStringUtils.generateUuid());
        mgRnrFileDTO.setRnrId(rnrId);
        mgRnrFileDTO.setFileType(fileType);
        mgRnrFileDTO.setFileSystemId(pic);
        mgRnrFileDTO.setTenantNo(UserSubjectUtil.getTenantNo());
        mgRnrFileDTO.setLiaisonId(liasionId);
        mgRnrFileDTO.setCreator(UserSubjectUtil.getUserId());
        mgRnrFileDTO.setOperator(UserSubjectUtil.getUserId());
        mgRnrFileDTO.setRnrBizzType(rnrBizzType);
        return mgRnrFileDTO;
    }



    /**
     * 获取文件类型
     *
     * @param certType 证书类型
     * @param index    索引
     */
    public static Integer getFileType(String certType, int index) {
        CertTypeEnum typeEnum = CertTypeEnum.getEnumByCode(certType);

        if (index < 0 || typeEnum == null || typeEnum.getFileTypes() == null || typeEnum.getFileTypes().length < 0) {
            throw new CuscUserException(ResponseCode.INVALID_DATA.getCode(), "证件类型【" + certType + "】错误");
        }

        //不能超过固定的文件数量
        if (typeEnum.isFixedSize() && index >= typeEnum.getFileTypes().length) {
            throw new CuscUserException(ResponseCode.INVALID_DATA.getCode(),
                    "证件【" + typeEnum.getName() + "】上传文件数超过指定数量【" + typeEnum.getFileTypes().length + "】");
        }

        if (index >= typeEnum.getFileTypes().length) {
            index = typeEnum.getFileTypes().length - 1;
        }
        return typeEnum.getFileTypes()[index].getCode();
    }

}
